@@ -268,7 +268,13 @@ class Normalizer(object):
         # Discard noise
         self._remove_novaclient_artifacts(image)
 
+        # If someone made a property called "properties" that contains a
+        # string (this has happened at least one time in the wild), the
+        # the rest of the normalization here goes belly up.
         properties = image.pop('properties', {})
+        if not isinstance(properties, dict):
+            properties = {'properties': properties}
+
         visibility = image.pop('visibility', None)
         protected = _to_bool(image.pop('protected', False))
 
@@ -318,7 +324,8 @@ class Normalizer(object):
         # Backwards compat with glance
         if not self.strict_mode:
             for key, val in properties.items():
-                new_image[key] = val
+                if key != 'properties':
+                    new_image[key] = val
             new_image['protected'] = protected
             new_image['metadata'] = properties
             new_image['created'] = new_image['created_at']
@@ -636,19 +643,14 @@ class Normalizer(object):
         description = project.pop('description', '')
         is_enabled = project.pop('enabled', True)
 
-        # Projects are global - strip region
-        location = self._get_current_location(project_id=project_id)
-        location['region_name'] = None
-
         # v3 additions
         domain_id = project.pop('domain_id', 'default')
         parent_id = project.pop('parent_id', None)
         is_domain = project.pop('is_domain', False)
 
         # Projects have a special relationship with location
+        location = self._get_identity_location()
         location['project']['domain_id'] = domain_id
-        location['project']['domain_name'] = None
-        location['project']['name'] = None
         location['project']['id'] = parent_id
 
         ret = munch.Munch(
@@ -658,13 +660,13 @@ class Normalizer(object):
             description=description,
             is_enabled=is_enabled,
             is_domain=is_domain,
+            domain_id=domain_id,
             properties=project.copy()
         )
 
         # Backwards compat
         if not self.strict_mode:
             ret['enabled'] = is_enabled
-            ret['domain_id'] = domain_id
             ret['parent_id'] = parent_id
             for key, val in ret['properties'].items():
                 ret.setdefault(key, val)
@@ -1082,3 +1084,21 @@ class Normalizer(object):
         # TODO(mordred) Normalize this resource
 
         return machine
+
+    def _normalize_roles(self, roles):
+        """Normalize Keystone roles"""
+        ret = []
+        for role in roles:
+            ret.append(self._normalize_role(role))
+        return ret
+
+    def _normalize_role(self, role):
+        """Normalize Identity roles."""
+
+        return munch.Munch(
+            id=role.get('id'),
+            name=role.get('name'),
+            domain_id=role.get('domain_id'),
+            location=self._get_identity_location(),
+            properties={},
+        )
