@@ -37,7 +37,7 @@ class OpenStackCloudException(Exception):
 
     def log_error(self, logger=None):
         if not logger:
-            logger = _log.setup_logging(__name__)
+            logger = _log.setup_logging('shade.exc')
         if self.inner_exception and self.inner_exception[1]:
             logger.error(self.orig_message, exc_info=self.inner_exception)
 
@@ -54,6 +54,16 @@ class OpenStackCloudException(Exception):
         return message
 
 
+class OpenStackCloudCreateException(OpenStackCloudException):
+
+    def __init__(self, resource, resource_id, extra_data=None, **kwargs):
+        super(OpenStackCloudCreateException, self).__init__(
+            message="Error creating {resource}: {resource_id}".format(
+                resource=resource, resource_id=resource_id),
+            extra_data=extra_data, **kwargs)
+        self.resource_id = resource_id
+
+
 class OpenStackCloudTimeout(OpenStackCloudException):
     pass
 
@@ -88,6 +98,32 @@ class OpenStackCloudURINotFound(OpenStackCloudHTTPError):
 OpenStackCloudResourceNotFound = OpenStackCloudURINotFound
 
 
+def _log_response_extras(response):
+    # Sometimes we get weird HTML errors. This is usually from load balancers
+    # or other things. Log them to a special logger so that they can be
+    # toggled indepdently - and at debug level so that a person logging
+    # shade.* only gets them at debug.
+    if response.headers.get('content-type') != 'text/html':
+        return
+    try:
+        if int(response.headers.get('content-length', 0)) == 0:
+            return
+    except Exception:
+        return
+    logger = _log.setup_logging('shade.http')
+    if response.reason:
+        logger.debug(
+            "Non-standard error '{reason}' returned from {url}:".format(
+                reason=response.reason,
+                url=response.url))
+    else:
+        logger.debug(
+            "Non-standard error returned from {url}:".format(
+                url=response.url))
+    for response_line in response.text.split('\n'):
+        logger.debug(response_line)
+
+
 # Logic shamelessly stolen from requests
 def raise_from_response(response, error_message=None):
     msg = ''
@@ -103,8 +139,9 @@ def raise_from_response(response, error_message=None):
         details = response.json()
         # Nova returns documents that look like
         # {statusname: 'message': message, 'code': code}
-        if len(details.keys()) == 1:
-            detail_key = details.keys()[0]
+        detail_keys = list(details.keys())
+        if len(detail_keys) == 1:
+            detail_key = detail_keys[0]
             detail_message = details[detail_key].get('message')
             if detail_message:
                 remote_error += " {message}".format(message=detail_message)
@@ -112,6 +149,8 @@ def raise_from_response(response, error_message=None):
         if response.reason:
             remote_error += " {reason}".format(reason=response.reason)
 
+    _log_response_extras(response)
+
     if error_message:
         msg = '{error_message}. ({code}) {source} {remote_error}'.format(
             error_message=error_message,
