@@ -127,9 +127,14 @@ class TestUsers(base.KeystoneBaseFunctionalTestCase):
         self.assertEqual(user_name, new_user['name'])
         self.assertEqual(user_email, new_user['email'])
         self.assertTrue(new_user['enabled'])
+        self.assertTrue(self.operator_cloud.grant_role(
+            'Member', user=user['id'], project='demo', wait=True))
+        self.addCleanup(
+            self.operator_cloud.revoke_role,
+            'Member', user=user['id'], project='demo', wait=True)
         self.assertIsNotNone(operator_cloud(
-            username=user_name, password='new_secret',
-            auth_url=self.operator_cloud.auth['auth_url']).keystone_client)
+            cloud=self._demo_name,
+            username=user_name, password='new_secret').service_catalog)
 
     def test_users_and_groups(self):
         i_ver = self.operator_cloud.cloud_config.get_api_version('identity')
